Data obtained via this package will automatically translate internal CMHC quality labels
using this translation vector, this named vector is useful when working with CMHC data obtained from other
sources like sporadic excel sheets or data scraped from PDF reports.